@@ -2,7 +2,7 @@
    drvSAMPL.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993,1994,1995,1996,1997 Wolfgang Glunz, Wolfgang.Glunz@mchp.siemens.de
+   Copyright (C) 1993,1994,1995,1996,1997,1998 Wolfgang Glunz, wglunz@geocities.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,36 +19,15 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
-
-#include <stdio.h>
-// rcw2: work round case insensitivity in RiscOS
-#ifdef riscos
-  #include "unix:string.h"
-#else
-  #include <string.h>
-#endif
-#include <stdlib.h>
 #include "drvsampl.h"
+#include I_fstream
+#include I_stdio
+#include I_stdlib
 
-drvSAMPL::drvSAMPL(const char * driveroptions_p,ostream & theoutStream,ostream & theerrStream): // Constructor
-	drvbase(driveroptions_p,theoutStream,theerrStream,
-		1, // if backend supports subpathes, else 0
-		   // if subpathes are supported, the backend must deal with
-		   // sequences of the following form
-		   // moveto (start of subpath)
-		   // lineto (a line segment)
-		   // lineto 
-		   // moveto (start of a new subpath)
-		   // lineto (a line segment)
-		   // lineto 
-		   //
-		   // If this argument is set to 0 each subpath is drawn 
-		   // individually which might not necessarily represent
-		   // the original drawing.
 
-		1,  // if backend supports curves, else 0
-		0  // if backend supports elements with fill and edges
-	)
+drvSAMPL::derivedConstructor(drvSAMPL):
+//(const char * driveroptions_p,ostream & theoutStream,ostream & theerrStream): // Constructor
+	constructBase
 {
 // driver specific initializations
 // and writing of header to output file
@@ -117,8 +96,9 @@ void drvSAMPL::close_page()
 
 void drvSAMPL::show_text(const TextInfo & textinfo)
 {
-	outf << "Text String : " << textinfo.thetext << endl;
+	outf << "Text String : " << textinfo.thetext.value() << endl;
 	outf << '\t' << "X " << textinfo.x << " Y " << textinfo.y << endl;
+	outf << '\t' << "X_END " << textinfo.x_end << " Y_END " << textinfo.y_end << endl;
 	outf << '\t' << "currentFontName: " <<  textinfo.currentFontName.value() << endl;
 	outf << '\t' << "is_non_standard_font: " <<  textinfo.is_non_standard_font << endl;
 	outf << '\t' << "currentFontFamilyName: " << textinfo.currentFontFamilyName.value() << endl;
@@ -172,3 +152,64 @@ void drvSAMPL::show_rectangle(const float llx, const float lly, const float urx,
 // just do show_path for a first guess
 	show_path();
 }
+void drvSAMPL::show_image(const Image & imageinfo)
+{
+
+outf << "Image:\n";
+outf << "\ttype: ";
+	switch (imageinfo.type) {
+	case colorimage : outf << " colorimage\n" ; break;
+	case normalimage : outf << " normalimage\n" ; break;
+	case imagemask : outf << " imagemask\n" ; break;
+	default: break;
+	}
+outf << "\theight: " << imageinfo.height << endl;
+outf << "\twidth: " << imageinfo.width << endl;
+outf << "\tbits/component: " << imageinfo.bits << endl;
+outf << "\tnumber of color components: " << imageinfo.ncomp << endl;
+outf << "\timageMatrix: ";
+{ for (unsigned int i = 0; i < 6 ; i++ ) {
+	outf << imageinfo.imageMatrix[i] << ' ';
+	}
+}
+outf << endl;
+outf << "\tnormalizedImageCurrentMatrix: ";
+{ for (unsigned int i = 0; i < 6 ; i++ ) {
+	outf << imageinfo.normalizedImageCurrentMatrix[i] << ' ';
+	}
+}
+outf << endl;
+outf << "\tpolarity: " << imageinfo.polarity << endl;
+{ 
+	for  (unsigned int i = 0 ; i < imageinfo.nextfreedataitem ; i++) {
+		if (!(i%8)) outf << "\n\t " << i << ":\t";
+		outf << (int) imageinfo.data[i] << ' '; 
+	}
+}
+outf << endl;
+}
+
+static DriverDescriptionT<drvSAMPL> D_sampl("sample","sample driver: if you don't want to see this, uncomment the corresponding line in makefile and make again","sam",
+								 
+		true, // backend supports subpathes
+		   // if subpathes are supported, the backend must deal with
+		   // sequences of the following form
+		   // moveto (start of subpath)
+		   // lineto (a line segment)
+		   // lineto 
+		   // moveto (start of a new subpath)
+		   // lineto (a line segment)
+		   // lineto 
+		   //
+		   // If this argument is set to false each subpath is drawn 
+		   // individually which might not necessarily represent
+		   // the original drawing.
+
+		true, // backend supports curves
+		false, // backend supports elements which are filled and have edges 
+		true, // backend supports text
+		true, // backend supports Images
+		DriverDescription::normalopen,
+		true); // if format supports multiple pages in one file
+
+ 
