@@ -5,7 +5,7 @@
    drvTGIF.h : This file is part of pstoedit
    Interface for new driver backends
 
-   Copyright (C) 1993,1994,1995,1996,1997 Wolfgang Glunz, Wolfgang.Glunz@mchp.siemens.de
+   Copyright (C) 1993,1994,1995,1996,1997,1998 Wolfgang Glunz, wglunz@geocities.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,17 +22,15 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
-#include <fstream.h>
 
-// for tmpnam
-#include <stdio.h>
 #include "drvbase.h"
 
 class drvTGIF : public drvbase {
 
 public:
 
-	drvTGIF(const char * driveroptions_P,ostream & theoutStream,ostream & theerrStream ,float theMagnification); // Constructor
+	derivedConstructor(drvTGIF);
+	//(const char * driveroptions_P,ostream & theoutStream,ostream & theerrStream ,float theMagnification); // Constructor
 
 	~drvTGIF(); // Destructor
 
@@ -40,7 +38,8 @@ private:
 	TempFile      tempFile;
 	ofstream     &buffer;
 	int             objectId;
-	const float     magnification;	
+	bool		textAsAttribute; // show text a HREF attribute
+//	const float     magnification;	
 
 #include "drvfuncs.h"
 
